Documentation
¶
Overview ¶
Package api provides primitives to interact with the openapi HTTP API.
Code generated by github.com/oapi-codegen/oapi-codegen/v2 version v2.3.1-0.20240607100731-2f92e0e4b159 DO NOT EDIT.
Index ¶
- func AcceptMiddleware(f strictnethttp.StrictHTTPHandlerFunc, operationID string) strictnethttp.StrictHTTPHandlerFunc
- func GetSwagger() (swagger *openapi3.T, err error)
- func Handler(si ServerInterface) http.Handler
- func HandlerFromMux(si ServerInterface, m *http.ServeMux) http.Handler
- func HandlerFromMuxWithBaseURL(si ServerInterface, m *http.ServeMux, baseURL string) http.Handler
- func HandlerWithOptions(si ServerInterface, options StdHTTPServerOptions) http.Handler
- func PathToRawSpec(pathToFile string) map[string]func() ([]byte, error)
- func StatusCode(err error) int
- func WantWebp(ctx context.Context) bool
- type App
- type AppInstanceDetail
- type AppInstanceSummary
- type ChannelDetail
- type ChannelRef
- type ChannelSummary
- type ClearChannelPush200Response
- type ClearChannelPush404JSONResponse
- type ClearChannelPushRequestObject
- type ClearChannelPushResponseObject
- type ClearChannelPushdefaultJSONResponse
- type ClearDevicePush200Response
- type ClearDevicePush404JSONResponse
- type ClearDevicePush409JSONResponse
- type ClearDevicePushRequestObject
- type ClearDevicePushResponseObject
- type ClearDevicePushdefaultJSONResponse
- type CreateChannel201JSONResponse
- type CreateChannelApplet201JSONResponse
- type CreateChannelApplet400JSONResponse
- type CreateChannelApplet404JSONResponse
- type CreateChannelAppletJSONRequestBody
- type CreateChannelAppletRequestObject
- type CreateChannelAppletResponseObject
- type CreateChannelAppletdefaultJSONResponse
- type CreateChannelJSONRequestBody
- type CreateChannelRequestObject
- type CreateChannelResponseObject
- type CreateChanneldefaultJSONResponse
- type DefaultErrorResponse
- type DefaultErrorResponseJSONResponse
- type DeleteChannel200Response
- type DeleteChannel409JSONResponse
- type DeleteChannelApplet200Response
- type DeleteChannelAppletRequestObject
- type DeleteChannelAppletResponseObject
- type DeleteChannelAppletdefaultJSONResponse
- type DeleteChannelRequestObject
- type DeleteChannelResponseObject
- type DeleteChanneldefaultJSONResponse
- type DeleteDevice200Response
- type DeleteDeviceRequestObject
- type DeleteDeviceResponseObject
- type DeleteDevicedefaultJSONResponse
- type DeviceRef
- type DeviceSummary
- type Error
- type FindChannelByUUID200ImagewebpResponse
- type FindChannelByUUID200JSONResponse
- type FindChannelByUUIDRequestObject
- type FindChannelByUUIDResponseObject
- type FindChannelByUUIDdefaultJSONResponse
- type GetAppletByID200JSONResponse
- type GetAppletByID404JSONResponse
- type GetAppletByIDRequestObject
- type GetAppletByIDResponseObject
- type GetAppletByIDdefaultJSONResponse
- type GetApplets200JSONResponse
- type GetAppletsParams
- type GetAppletsRequestObject
- type GetAppletsResponseObject
- type GetAppletsdefaultJSONResponse
- type GetChannels200JSONResponse
- type GetChannelsRequestObject
- type GetChannelsResponseObject
- type GetChannelsdefaultJSONResponse
- type GetDeviceByUUID200JSONResponse
- type GetDeviceByUUIDRequestObject
- type GetDeviceByUUIDResponseObject
- type GetDeviceByUUIDdefaultJSONResponse
- type GetDevices200JSONResponse
- type GetDevicesRequestObject
- type GetDevicesResponseObject
- type GetDevicesdefaultJSONResponse
- type GetLocationByPlaceID200JSONResponse
- type GetLocationByPlaceID404JSONResponse
- type GetLocationByPlaceIDRequestObject
- type GetLocationByPlaceIDResponseObject
- type GetLocationByPlaceIDdefaultJSONResponse
- type GetSessions200JSONResponse
- type GetSessionsRequestObject
- type GetSessionsResponseObject
- type GetSessionsdefaultJSONResponse
- type InvalidParamFormatError
- type Location
- type MiddlewareFunc
- type Notification
- type PatchChannel200Response
- type PatchChannelApplet200Response
- type PatchChannelAppletJSONBody
- type PatchChannelAppletJSONRequestBody
- type PatchChannelAppletRequestObject
- type PatchChannelAppletResponseObject
- type PatchChannelAppletdefaultJSONResponse
- type PatchChannelJSONBody
- type PatchChannelJSONRequestBody
- type PatchChannelRequestObject
- type PatchChannelResponseObject
- type PatchChanneldefaultJSONResponse
- type PatchDevice200Response
- type PatchDeviceJSONBody
- type PatchDeviceJSONRequestBody
- type PatchDeviceRequestObject
- type PatchDeviceResponseObject
- type PatchDevicedefaultJSONResponse
- type PushAppletRequest
- type PushChannelContent200Response
- type PushChannelContent400JSONResponse
- type PushChannelContent404JSONResponse
- type PushChannelContentJSONRequestBody
- type PushChannelContentMultipartBody
- type PushChannelContentMultipartRequestBody
- type PushChannelContentRequestObject
- type PushChannelContentResponseObject
- type PushChannelContentdefaultJSONResponse
- type PushDeviceContent200Response
- type PushDeviceContent400JSONResponse
- type PushDeviceContent404JSONResponse
- type PushDeviceContent409JSONResponse
- type PushDeviceContentJSONRequestBody
- type PushDeviceContentMultipartBody
- type PushDeviceContentMultipartRequestBody
- type PushDeviceContentRequestObject
- type PushDeviceContentResponseObject
- type PushDeviceContentdefaultJSONResponse
- type RenderApplet200ImagewebpResponse
- type RenderApplet404JSONResponse
- type RenderAppletParams
- type RenderAppletRequestObject
- type RenderAppletResponseObject
- type RenderAppletdefaultJSONResponse
- type RequiredHeaderError
- type RequiredParamError
- type Schema
- type SchemaField
- type SchemaOption
- type SchemaVisibility
- type SearchLocations200JSONResponse
- type SearchLocationsParams
- type SearchLocationsRequestObject
- type SearchLocationsResponseObject
- type SearchLocationsdefaultJSONResponse
- type Server
- func (s *Server) ClearChannelPush(ctx context.Context, request ClearChannelPushRequestObject) (ClearChannelPushResponseObject, error)
- func (s *Server) ClearDevicePush(ctx context.Context, request ClearDevicePushRequestObject) (ClearDevicePushResponseObject, error)
- func (s *Server) CreateChannel(ctx context.Context, request CreateChannelRequestObject) (CreateChannelResponseObject, error)
- func (s *Server) CreateChannelApplet(ctx context.Context, request CreateChannelAppletRequestObject) (CreateChannelAppletResponseObject, error)
- func (s *Server) DeleteChannel(ctx context.Context, request DeleteChannelRequestObject) (DeleteChannelResponseObject, error)
- func (s *Server) DeleteChannelApplet(ctx context.Context, request DeleteChannelAppletRequestObject) (DeleteChannelAppletResponseObject, error)
- func (s *Server) DeleteDevice(ctx context.Context, request DeleteDeviceRequestObject) (DeleteDeviceResponseObject, error)
- func (s *Server) FindChannelByUUID(ctx context.Context, request FindChannelByUUIDRequestObject) (FindChannelByUUIDResponseObject, error)
- func (s *Server) GetAppletByID(ctx context.Context, request GetAppletByIDRequestObject) (GetAppletByIDResponseObject, error)
- func (s *Server) GetApplets(ctx context.Context, request GetAppletsRequestObject) (GetAppletsResponseObject, error)
- func (s *Server) GetChannels(ctx context.Context, request GetChannelsRequestObject) (GetChannelsResponseObject, error)
- func (s *Server) GetDeviceByUUID(ctx context.Context, request GetDeviceByUUIDRequestObject) (GetDeviceByUUIDResponseObject, error)
- func (s *Server) GetDevices(ctx context.Context, request GetDevicesRequestObject) (GetDevicesResponseObject, error)
- func (s *Server) GetLocationByPlaceID(ctx context.Context, request GetLocationByPlaceIDRequestObject) (GetLocationByPlaceIDResponseObject, error)
- func (s *Server) GetSessions(ctx context.Context, request GetSessionsRequestObject) (GetSessionsResponseObject, error)
- func (s *Server) PatchChannel(ctx context.Context, request PatchChannelRequestObject) (PatchChannelResponseObject, error)
- func (s *Server) PatchChannelApplet(ctx context.Context, request PatchChannelAppletRequestObject) (PatchChannelAppletResponseObject, error)
- func (s *Server) PatchDevice(ctx context.Context, request PatchDeviceRequestObject) (PatchDeviceResponseObject, error)
- func (s *Server) PushChannelContent(ctx context.Context, request PushChannelContentRequestObject) (PushChannelContentResponseObject, error)
- func (s *Server) PushDeviceContent(ctx context.Context, request PushDeviceContentRequestObject) (PushDeviceContentResponseObject, error)
- func (s *Server) RenderApplet(ctx context.Context, request RenderAppletRequestObject) (RenderAppletResponseObject, error)
- func (s *Server) SearchLocations(ctx context.Context, request SearchLocationsRequestObject) (SearchLocationsResponseObject, error)
- type ServerInterface
- type ServerInterfaceWrapper
- func (siw *ServerInterfaceWrapper) ClearChannelPush(w http.ResponseWriter, r *http.Request)
- func (siw *ServerInterfaceWrapper) ClearDevicePush(w http.ResponseWriter, r *http.Request)
- func (siw *ServerInterfaceWrapper) CreateChannel(w http.ResponseWriter, r *http.Request)
- func (siw *ServerInterfaceWrapper) CreateChannelApplet(w http.ResponseWriter, r *http.Request)
- func (siw *ServerInterfaceWrapper) DeleteChannel(w http.ResponseWriter, r *http.Request)
- func (siw *ServerInterfaceWrapper) DeleteChannelApplet(w http.ResponseWriter, r *http.Request)
- func (siw *ServerInterfaceWrapper) DeleteDevice(w http.ResponseWriter, r *http.Request)
- func (siw *ServerInterfaceWrapper) FindChannelByUUID(w http.ResponseWriter, r *http.Request)
- func (siw *ServerInterfaceWrapper) GetAppletByID(w http.ResponseWriter, r *http.Request)
- func (siw *ServerInterfaceWrapper) GetApplets(w http.ResponseWriter, r *http.Request)
- func (siw *ServerInterfaceWrapper) GetChannels(w http.ResponseWriter, r *http.Request)
- func (siw *ServerInterfaceWrapper) GetDeviceByUUID(w http.ResponseWriter, r *http.Request)
- func (siw *ServerInterfaceWrapper) GetDevices(w http.ResponseWriter, r *http.Request)
- func (siw *ServerInterfaceWrapper) GetLocationByPlaceID(w http.ResponseWriter, r *http.Request)
- func (siw *ServerInterfaceWrapper) GetSessions(w http.ResponseWriter, r *http.Request)
- func (siw *ServerInterfaceWrapper) PatchChannel(w http.ResponseWriter, r *http.Request)
- func (siw *ServerInterfaceWrapper) PatchChannelApplet(w http.ResponseWriter, r *http.Request)
- func (siw *ServerInterfaceWrapper) PatchDevice(w http.ResponseWriter, r *http.Request)
- func (siw *ServerInterfaceWrapper) PushChannelContent(w http.ResponseWriter, r *http.Request)
- func (siw *ServerInterfaceWrapper) PushDeviceContent(w http.ResponseWriter, r *http.Request)
- func (siw *ServerInterfaceWrapper) RenderApplet(w http.ResponseWriter, r *http.Request)
- func (siw *ServerInterfaceWrapper) SearchLocations(w http.ResponseWriter, r *http.Request)
- type SessionSummary
- type StdHTTPServerOptions
- type StrictHTTPServerOptions
- type StrictHandlerFunc
- type StrictMiddlewareFunc
- type StrictServerInterface
- type TooManyValuesForParamError
- type UnescapedCookieParamError
- type UnmarshalingParamError
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func AcceptMiddleware ¶
func AcceptMiddleware(f strictnethttp.StrictHTTPHandlerFunc, operationID string) strictnethttp.StrictHTTPHandlerFunc
func GetSwagger ¶
GetSwagger returns the Swagger specification corresponding to the generated code in this file. The external references of Swagger specification are resolved. The logic of resolving external references is tightly connected to "import-mapping" feature. Externally referenced files must be embedded in the corresponding golang packages. Urls can be supported but this task was out of the scope.
func Handler ¶
func Handler(si ServerInterface) http.Handler
Handler creates http.Handler with routing matching OpenAPI spec.
func HandlerFromMux ¶
func HandlerFromMux(si ServerInterface, m *http.ServeMux) http.Handler
HandlerFromMux creates http.Handler with routing matching OpenAPI spec based on the provided mux.
func HandlerWithOptions ¶
func HandlerWithOptions(si ServerInterface, options StdHTTPServerOptions) http.Handler
HandlerWithOptions creates http.Handler with additional options
func PathToRawSpec ¶
Constructs a synthetic filesystem for resolving external references when loading openapi specifications.
func StatusCode ¶
Types ¶
type App ¶
type App struct {
// Author Author of the app
Author string `json:"author"`
Description string `json:"description"`
// Id Unique ID of the app
Id string `json:"id"`
// Name Name of the app
Name string `json:"name"`
Schema *Schema `json:"schema,omitempty"`
// Summary Short summary of the app
Summary string `json:"summary"`
}
App defines model for App.
type AppInstanceDetail ¶
type AppInstanceDetail struct {
// AppID Applet ID
AppID string `json:"app-id"`
// Config Applet configuration
Config json.RawMessage `json:"config,omitempty"`
// Idx App position
Idx *int `json:"idx,omitempty"`
// UUID App instance UUID
UUID *openapi_types.UUID `json:"uuid,omitempty"`
}
AppInstanceDetail defines model for AppInstanceDetail.
type AppInstanceSummary ¶
type AppInstanceSummary struct {
// AppID Applet ID
AppID string `json:"app-id"`
// Config Applet configuration
Config json.RawMessage `json:"config,omitempty"`
// Idx App position
Idx *int `json:"idx,omitempty"`
}
AppInstanceSummary defines model for AppInstanceSummary.
type ChannelDetail ¶
type ChannelDetail struct {
Applets *[]AppInstanceDetail `json:"applets,omitempty"`
// Comment Comment for the channel
Comment *string `json:"comment,omitempty"`
// Name Name of the channel
Name string `json:"name"`
Subscribers *[]DeviceRef `json:"subscribers,omitempty"`
// UUID UUID of the channel
UUID *openapi_types.UUID `json:"uuid,omitempty"`
}
ChannelDetail defines model for ChannelDetail.
type ChannelRef ¶
type ChannelRef struct {
// Name Name of the channel
Name *string `json:"name,omitempty"`
// UUID UUID of the channel
UUID *openapi_types.UUID `json:"uuid,omitempty"`
}
ChannelRef defines model for ChannelRef.
type ChannelSummary ¶
type ChannelSummary struct {
// Comment Comment for the channel
Comment *string `json:"comment,omitempty"`
// Name Name of the channel
Name string `json:"name"`
// UUID UUID of the channel
UUID *openapi_types.UUID `json:"uuid,omitempty"`
}
ChannelSummary defines model for ChannelSummary.
type ClearChannelPush200Response ¶
type ClearChannelPush200Response struct {
}
func (ClearChannelPush200Response) VisitClearChannelPushResponse ¶
func (response ClearChannelPush200Response) VisitClearChannelPushResponse(w http.ResponseWriter) error
type ClearChannelPush404JSONResponse ¶
type ClearChannelPush404JSONResponse Error
func (ClearChannelPush404JSONResponse) VisitClearChannelPushResponse ¶
func (response ClearChannelPush404JSONResponse) VisitClearChannelPushResponse(w http.ResponseWriter) error
type ClearChannelPushRequestObject ¶
type ClearChannelPushRequestObject struct {
UUID openapi_types.UUID `json:"uuid"`
}
type ClearChannelPushResponseObject ¶
type ClearChannelPushResponseObject interface {
VisitClearChannelPushResponse(w http.ResponseWriter) error
}
type ClearChannelPushdefaultJSONResponse ¶
func (ClearChannelPushdefaultJSONResponse) VisitClearChannelPushResponse ¶
func (response ClearChannelPushdefaultJSONResponse) VisitClearChannelPushResponse(w http.ResponseWriter) error
type ClearDevicePush200Response ¶
type ClearDevicePush200Response struct {
}
func (ClearDevicePush200Response) VisitClearDevicePushResponse ¶
func (response ClearDevicePush200Response) VisitClearDevicePushResponse(w http.ResponseWriter) error
type ClearDevicePush404JSONResponse ¶
type ClearDevicePush404JSONResponse Error
func (ClearDevicePush404JSONResponse) VisitClearDevicePushResponse ¶
func (response ClearDevicePush404JSONResponse) VisitClearDevicePushResponse(w http.ResponseWriter) error
type ClearDevicePush409JSONResponse ¶
type ClearDevicePush409JSONResponse Error
func (ClearDevicePush409JSONResponse) VisitClearDevicePushResponse ¶
func (response ClearDevicePush409JSONResponse) VisitClearDevicePushResponse(w http.ResponseWriter) error
type ClearDevicePushRequestObject ¶
type ClearDevicePushRequestObject struct {
UUID openapi_types.UUID `json:"uuid"`
}
type ClearDevicePushResponseObject ¶
type ClearDevicePushResponseObject interface {
VisitClearDevicePushResponse(w http.ResponseWriter) error
}
type ClearDevicePushdefaultJSONResponse ¶
func (ClearDevicePushdefaultJSONResponse) VisitClearDevicePushResponse ¶
func (response ClearDevicePushdefaultJSONResponse) VisitClearDevicePushResponse(w http.ResponseWriter) error
type CreateChannel201JSONResponse ¶
type CreateChannel201JSONResponse ChannelDetail
func (CreateChannel201JSONResponse) VisitCreateChannelResponse ¶
func (response CreateChannel201JSONResponse) VisitCreateChannelResponse(w http.ResponseWriter) error
type CreateChannelApplet201JSONResponse ¶
type CreateChannelApplet201JSONResponse AppInstanceDetail
func (CreateChannelApplet201JSONResponse) VisitCreateChannelAppletResponse ¶
func (response CreateChannelApplet201JSONResponse) VisitCreateChannelAppletResponse(w http.ResponseWriter) error
type CreateChannelApplet400JSONResponse ¶
type CreateChannelApplet400JSONResponse Error
func (CreateChannelApplet400JSONResponse) VisitCreateChannelAppletResponse ¶
func (response CreateChannelApplet400JSONResponse) VisitCreateChannelAppletResponse(w http.ResponseWriter) error
type CreateChannelApplet404JSONResponse ¶
type CreateChannelApplet404JSONResponse Error
func (CreateChannelApplet404JSONResponse) VisitCreateChannelAppletResponse ¶
func (response CreateChannelApplet404JSONResponse) VisitCreateChannelAppletResponse(w http.ResponseWriter) error
type CreateChannelAppletJSONRequestBody ¶
type CreateChannelAppletJSONRequestBody = AppInstanceSummary
CreateChannelAppletJSONRequestBody defines body for CreateChannelApplet for application/json ContentType.
type CreateChannelAppletRequestObject ¶
type CreateChannelAppletRequestObject struct {
ChannelUUID openapi_types.UUID `json:"channelUUID"`
Body *CreateChannelAppletJSONRequestBody
}
type CreateChannelAppletResponseObject ¶
type CreateChannelAppletResponseObject interface {
VisitCreateChannelAppletResponse(w http.ResponseWriter) error
}
type CreateChannelAppletdefaultJSONResponse ¶
func (CreateChannelAppletdefaultJSONResponse) VisitCreateChannelAppletResponse ¶
func (response CreateChannelAppletdefaultJSONResponse) VisitCreateChannelAppletResponse(w http.ResponseWriter) error
type CreateChannelJSONRequestBody ¶
type CreateChannelJSONRequestBody = ChannelSummary
CreateChannelJSONRequestBody defines body for CreateChannel for application/json ContentType.
type CreateChannelRequestObject ¶
type CreateChannelRequestObject struct {
Body *CreateChannelJSONRequestBody
}
type CreateChannelResponseObject ¶
type CreateChannelResponseObject interface {
VisitCreateChannelResponse(w http.ResponseWriter) error
}
type CreateChanneldefaultJSONResponse ¶
func (CreateChanneldefaultJSONResponse) VisitCreateChannelResponse ¶
func (response CreateChanneldefaultJSONResponse) VisitCreateChannelResponse(w http.ResponseWriter) error
type DefaultErrorResponse ¶
type DefaultErrorResponse = Error
DefaultErrorResponse defines model for DefaultErrorResponse.
type DefaultErrorResponseJSONResponse ¶
type DefaultErrorResponseJSONResponse Error
type DeleteChannel200Response ¶
type DeleteChannel200Response struct {
}
func (DeleteChannel200Response) VisitDeleteChannelResponse ¶
func (response DeleteChannel200Response) VisitDeleteChannelResponse(w http.ResponseWriter) error
type DeleteChannel409JSONResponse ¶
type DeleteChannel409JSONResponse Error
func (DeleteChannel409JSONResponse) VisitDeleteChannelResponse ¶
func (response DeleteChannel409JSONResponse) VisitDeleteChannelResponse(w http.ResponseWriter) error
type DeleteChannelApplet200Response ¶
type DeleteChannelApplet200Response struct {
}
func (DeleteChannelApplet200Response) VisitDeleteChannelAppletResponse ¶
func (response DeleteChannelApplet200Response) VisitDeleteChannelAppletResponse(w http.ResponseWriter) error
type DeleteChannelAppletRequestObject ¶
type DeleteChannelAppletRequestObject struct {
ChannelUUID openapi_types.UUID `json:"channelUUID"`
AppletUUID openapi_types.UUID `json:"appletUUID"`
}
type DeleteChannelAppletResponseObject ¶
type DeleteChannelAppletResponseObject interface {
VisitDeleteChannelAppletResponse(w http.ResponseWriter) error
}
type DeleteChannelAppletdefaultJSONResponse ¶
func (DeleteChannelAppletdefaultJSONResponse) VisitDeleteChannelAppletResponse ¶
func (response DeleteChannelAppletdefaultJSONResponse) VisitDeleteChannelAppletResponse(w http.ResponseWriter) error
type DeleteChannelRequestObject ¶
type DeleteChannelRequestObject struct {
UUID openapi_types.UUID `json:"uuid"`
}
type DeleteChannelResponseObject ¶
type DeleteChannelResponseObject interface {
VisitDeleteChannelResponse(w http.ResponseWriter) error
}
type DeleteChanneldefaultJSONResponse ¶
func (DeleteChanneldefaultJSONResponse) VisitDeleteChannelResponse ¶
func (response DeleteChanneldefaultJSONResponse) VisitDeleteChannelResponse(w http.ResponseWriter) error
type DeleteDevice200Response ¶
type DeleteDevice200Response struct {
}
func (DeleteDevice200Response) VisitDeleteDeviceResponse ¶
func (response DeleteDevice200Response) VisitDeleteDeviceResponse(w http.ResponseWriter) error
type DeleteDeviceRequestObject ¶
type DeleteDeviceRequestObject struct {
UUID openapi_types.UUID `json:"uuid"`
}
type DeleteDeviceResponseObject ¶
type DeleteDeviceResponseObject interface {
VisitDeleteDeviceResponse(w http.ResponseWriter) error
}
type DeleteDevicedefaultJSONResponse ¶
func (DeleteDevicedefaultJSONResponse) VisitDeleteDeviceResponse ¶
func (response DeleteDevicedefaultJSONResponse) VisitDeleteDeviceResponse(w http.ResponseWriter) error
type DeviceRef ¶
type DeviceRef struct {
// Name Name of the channel
Name *string `json:"name,omitempty"`
// UUID UUID of the device
UUID *openapi_types.UUID `json:"uuid,omitempty"`
}
DeviceRef defines model for DeviceRef.
type DeviceSummary ¶
type DeviceSummary struct {
Channel *ChannelRef `json:"channel,omitempty"`
// Connected Whether the device is currently connected
Connected *bool `json:"connected,omitempty"`
// CurrentIP Current IP address if connected
CurrentIP *string `json:"current-ip,omitempty"`
// LastConnectTime Last connection timestamp
LastConnectTime *time.Time `json:"last-connect-time,omitempty"`
// LastDisconnectTime Last disconnection timestamp
LastDisconnectTime *time.Time `json:"last-disconnect-time,omitempty"`
// LastIP Last known IP address
LastIP *string `json:"last-ip,omitempty"`
// Name Name of the channel
Name *string `json:"name,omitempty"`
// UUID UUID of the device
UUID *openapi_types.UUID `json:"uuid,omitempty"`
}
DeviceSummary defines model for DeviceSummary.
type Error ¶
type Error struct {
// Code Error code
Code int32 `json:"code"`
// Message Error message
Message string `json:"message"`
}
Error defines model for Error.
func RenderError ¶
type FindChannelByUUID200ImagewebpResponse ¶
func (FindChannelByUUID200ImagewebpResponse) VisitFindChannelByUUIDResponse ¶
func (response FindChannelByUUID200ImagewebpResponse) VisitFindChannelByUUIDResponse(w http.ResponseWriter) error
type FindChannelByUUID200JSONResponse ¶
type FindChannelByUUID200JSONResponse ChannelDetail
func (FindChannelByUUID200JSONResponse) VisitFindChannelByUUIDResponse ¶
func (response FindChannelByUUID200JSONResponse) VisitFindChannelByUUIDResponse(w http.ResponseWriter) error
type FindChannelByUUIDRequestObject ¶
type FindChannelByUUIDRequestObject struct {
UUID openapi_types.UUID `json:"uuid"`
}
type FindChannelByUUIDResponseObject ¶
type FindChannelByUUIDResponseObject interface {
VisitFindChannelByUUIDResponse(w http.ResponseWriter) error
}
type FindChannelByUUIDdefaultJSONResponse ¶
func (FindChannelByUUIDdefaultJSONResponse) VisitFindChannelByUUIDResponse ¶
func (response FindChannelByUUIDdefaultJSONResponse) VisitFindChannelByUUIDResponse(w http.ResponseWriter) error
type GetAppletByID200JSONResponse ¶
type GetAppletByID200JSONResponse App
func (GetAppletByID200JSONResponse) VisitGetAppletByIDResponse ¶
func (response GetAppletByID200JSONResponse) VisitGetAppletByIDResponse(w http.ResponseWriter) error
type GetAppletByID404JSONResponse ¶
type GetAppletByID404JSONResponse Error
func (GetAppletByID404JSONResponse) VisitGetAppletByIDResponse ¶
func (response GetAppletByID404JSONResponse) VisitGetAppletByIDResponse(w http.ResponseWriter) error
type GetAppletByIDRequestObject ¶
type GetAppletByIDRequestObject struct {
Id string `json:"id"`
}
type GetAppletByIDResponseObject ¶
type GetAppletByIDResponseObject interface {
VisitGetAppletByIDResponse(w http.ResponseWriter) error
}
type GetAppletByIDdefaultJSONResponse ¶
func (GetAppletByIDdefaultJSONResponse) VisitGetAppletByIDResponse ¶
func (response GetAppletByIDdefaultJSONResponse) VisitGetAppletByIDResponse(w http.ResponseWriter) error
type GetApplets200JSONResponse ¶
type GetApplets200JSONResponse []App
func (GetApplets200JSONResponse) VisitGetAppletsResponse ¶
func (response GetApplets200JSONResponse) VisitGetAppletsResponse(w http.ResponseWriter) error
type GetAppletsParams ¶
type GetAppletsParams struct {
// Id Id to filter by
Id *string `form:"id,omitempty" json:"id,omitempty"`
}
GetAppletsParams defines parameters for GetApplets.
type GetAppletsRequestObject ¶
type GetAppletsRequestObject struct {
Params GetAppletsParams
}
type GetAppletsResponseObject ¶
type GetAppletsResponseObject interface {
VisitGetAppletsResponse(w http.ResponseWriter) error
}
type GetAppletsdefaultJSONResponse ¶
func (GetAppletsdefaultJSONResponse) VisitGetAppletsResponse ¶
func (response GetAppletsdefaultJSONResponse) VisitGetAppletsResponse(w http.ResponseWriter) error
type GetChannels200JSONResponse ¶
type GetChannels200JSONResponse []ChannelSummary
func (GetChannels200JSONResponse) VisitGetChannelsResponse ¶
func (response GetChannels200JSONResponse) VisitGetChannelsResponse(w http.ResponseWriter) error
type GetChannelsRequestObject ¶
type GetChannelsRequestObject struct {
}
type GetChannelsResponseObject ¶
type GetChannelsResponseObject interface {
VisitGetChannelsResponse(w http.ResponseWriter) error
}
type GetChannelsdefaultJSONResponse ¶
func (GetChannelsdefaultJSONResponse) VisitGetChannelsResponse ¶
func (response GetChannelsdefaultJSONResponse) VisitGetChannelsResponse(w http.ResponseWriter) error
type GetDeviceByUUID200JSONResponse ¶
type GetDeviceByUUID200JSONResponse DeviceSummary
func (GetDeviceByUUID200JSONResponse) VisitGetDeviceByUUIDResponse ¶
func (response GetDeviceByUUID200JSONResponse) VisitGetDeviceByUUIDResponse(w http.ResponseWriter) error
type GetDeviceByUUIDRequestObject ¶
type GetDeviceByUUIDRequestObject struct {
UUID openapi_types.UUID `json:"uuid"`
}
type GetDeviceByUUIDResponseObject ¶
type GetDeviceByUUIDResponseObject interface {
VisitGetDeviceByUUIDResponse(w http.ResponseWriter) error
}
type GetDeviceByUUIDdefaultJSONResponse ¶
func (GetDeviceByUUIDdefaultJSONResponse) VisitGetDeviceByUUIDResponse ¶
func (response GetDeviceByUUIDdefaultJSONResponse) VisitGetDeviceByUUIDResponse(w http.ResponseWriter) error
type GetDevices200JSONResponse ¶
type GetDevices200JSONResponse []DeviceSummary
func (GetDevices200JSONResponse) VisitGetDevicesResponse ¶
func (response GetDevices200JSONResponse) VisitGetDevicesResponse(w http.ResponseWriter) error
type GetDevicesRequestObject ¶
type GetDevicesRequestObject struct {
}
type GetDevicesResponseObject ¶
type GetDevicesResponseObject interface {
VisitGetDevicesResponse(w http.ResponseWriter) error
}
type GetDevicesdefaultJSONResponse ¶
func (GetDevicesdefaultJSONResponse) VisitGetDevicesResponse ¶
func (response GetDevicesdefaultJSONResponse) VisitGetDevicesResponse(w http.ResponseWriter) error
type GetLocationByPlaceID200JSONResponse ¶
type GetLocationByPlaceID200JSONResponse Location
func (GetLocationByPlaceID200JSONResponse) VisitGetLocationByPlaceIDResponse ¶
func (response GetLocationByPlaceID200JSONResponse) VisitGetLocationByPlaceIDResponse(w http.ResponseWriter) error
type GetLocationByPlaceID404JSONResponse ¶
type GetLocationByPlaceID404JSONResponse Error
func (GetLocationByPlaceID404JSONResponse) VisitGetLocationByPlaceIDResponse ¶
func (response GetLocationByPlaceID404JSONResponse) VisitGetLocationByPlaceIDResponse(w http.ResponseWriter) error
type GetLocationByPlaceIDRequestObject ¶
type GetLocationByPlaceIDRequestObject struct {
PlaceId string `json:"placeId"`
}
type GetLocationByPlaceIDResponseObject ¶
type GetLocationByPlaceIDResponseObject interface {
VisitGetLocationByPlaceIDResponse(w http.ResponseWriter) error
}
type GetLocationByPlaceIDdefaultJSONResponse ¶
func (GetLocationByPlaceIDdefaultJSONResponse) VisitGetLocationByPlaceIDResponse ¶
func (response GetLocationByPlaceIDdefaultJSONResponse) VisitGetLocationByPlaceIDResponse(w http.ResponseWriter) error
type GetSessions200JSONResponse ¶
type GetSessions200JSONResponse []SessionSummary
func (GetSessions200JSONResponse) VisitGetSessionsResponse ¶
func (response GetSessions200JSONResponse) VisitGetSessionsResponse(w http.ResponseWriter) error
type GetSessionsRequestObject ¶
type GetSessionsRequestObject struct {
}
type GetSessionsResponseObject ¶
type GetSessionsResponseObject interface {
VisitGetSessionsResponse(w http.ResponseWriter) error
}
type GetSessionsdefaultJSONResponse ¶
func (GetSessionsdefaultJSONResponse) VisitGetSessionsResponse ¶
func (response GetSessionsdefaultJSONResponse) VisitGetSessionsResponse(w http.ResponseWriter) error
type InvalidParamFormatError ¶
func (*InvalidParamFormatError) Error ¶
func (e *InvalidParamFormatError) Error() string
func (*InvalidParamFormatError) Unwrap ¶
func (e *InvalidParamFormatError) Unwrap() error
type Location ¶
type Location struct {
// Description Full location description (e.g. "Brooklyn, NY, USA")
Description string `json:"description"`
// Lat Latitude
Lat string `json:"lat"`
// Lng Longitude
Lng string `json:"lng"`
// Locality City/locality name
Locality string `json:"locality"`
// PlaceID Unique place identifier
PlaceID string `json:"place_id"`
// Timezone IANA timezone identifier (e.g. "America/New_York")
Timezone string `json:"timezone"`
}
Location defines model for Location.
type PatchChannel200Response ¶
type PatchChannel200Response struct {
}
func (PatchChannel200Response) VisitPatchChannelResponse ¶
func (response PatchChannel200Response) VisitPatchChannelResponse(w http.ResponseWriter) error
type PatchChannelApplet200Response ¶
type PatchChannelApplet200Response struct {
}
func (PatchChannelApplet200Response) VisitPatchChannelAppletResponse ¶
func (response PatchChannelApplet200Response) VisitPatchChannelAppletResponse(w http.ResponseWriter) error
type PatchChannelAppletJSONBody ¶
type PatchChannelAppletJSONBody struct {
// Config Applet configuration
Config json.RawMessage `json:"config,omitempty"`
// Idx App position
Idx *int `json:"idx,omitempty"`
}
PatchChannelAppletJSONBody defines parameters for PatchChannelApplet.
type PatchChannelAppletJSONRequestBody ¶
type PatchChannelAppletJSONRequestBody PatchChannelAppletJSONBody
PatchChannelAppletJSONRequestBody defines body for PatchChannelApplet for application/json ContentType.
type PatchChannelAppletRequestObject ¶
type PatchChannelAppletRequestObject struct {
ChannelUUID openapi_types.UUID `json:"channelUUID"`
AppletUUID openapi_types.UUID `json:"appletUUID"`
Body *PatchChannelAppletJSONRequestBody
}
type PatchChannelAppletResponseObject ¶
type PatchChannelAppletResponseObject interface {
VisitPatchChannelAppletResponse(w http.ResponseWriter) error
}
type PatchChannelAppletdefaultJSONResponse ¶
func (PatchChannelAppletdefaultJSONResponse) VisitPatchChannelAppletResponse ¶
func (response PatchChannelAppletdefaultJSONResponse) VisitPatchChannelAppletResponse(w http.ResponseWriter) error
type PatchChannelJSONBody ¶
type PatchChannelJSONBody struct {
// Comment Channel description
Comment *string `json:"comment,omitempty"`
// Name Channel name
Name *string `json:"name,omitempty"`
}
PatchChannelJSONBody defines parameters for PatchChannel.
type PatchChannelJSONRequestBody ¶
type PatchChannelJSONRequestBody PatchChannelJSONBody
PatchChannelJSONRequestBody defines body for PatchChannel for application/json ContentType.
type PatchChannelRequestObject ¶
type PatchChannelRequestObject struct {
UUID openapi_types.UUID `json:"uuid"`
Body *PatchChannelJSONRequestBody
}
type PatchChannelResponseObject ¶
type PatchChannelResponseObject interface {
VisitPatchChannelResponse(w http.ResponseWriter) error
}
type PatchChanneldefaultJSONResponse ¶
func (PatchChanneldefaultJSONResponse) VisitPatchChannelResponse ¶
func (response PatchChanneldefaultJSONResponse) VisitPatchChannelResponse(w http.ResponseWriter) error
type PatchDevice200Response ¶
type PatchDevice200Response struct {
}
func (PatchDevice200Response) VisitPatchDeviceResponse ¶
func (response PatchDevice200Response) VisitPatchDeviceResponse(w http.ResponseWriter) error
type PatchDeviceJSONBody ¶
type PatchDeviceJSONBody struct {
Channel *ChannelRef `json:"channel,omitempty"`
// Name Device name
Name *string `json:"name,omitempty"`
}
PatchDeviceJSONBody defines parameters for PatchDevice.
type PatchDeviceJSONRequestBody ¶
type PatchDeviceJSONRequestBody PatchDeviceJSONBody
PatchDeviceJSONRequestBody defines body for PatchDevice for application/json ContentType.
type PatchDeviceRequestObject ¶
type PatchDeviceRequestObject struct {
UUID openapi_types.UUID `json:"uuid"`
Body *PatchDeviceJSONRequestBody
}
type PatchDeviceResponseObject ¶
type PatchDeviceResponseObject interface {
VisitPatchDeviceResponse(w http.ResponseWriter) error
}
type PatchDevicedefaultJSONResponse ¶
func (PatchDevicedefaultJSONResponse) VisitPatchDeviceResponse ¶
func (response PatchDevicedefaultJSONResponse) VisitPatchDeviceResponse(w http.ResponseWriter) error
type PushAppletRequest ¶
type PushAppletRequest struct {
// Applet Applet ID from catalog
Applet string `json:"applet"`
// Config Applet configuration
Config *map[string]interface{} `json:"config,omitempty"`
// Duration Display duration in seconds (default 15, 0 for indefinite)
Duration *int `json:"duration,omitempty"`
}
PushAppletRequest defines model for PushAppletRequest.
type PushChannelContent200Response ¶
type PushChannelContent200Response struct {
}
func (PushChannelContent200Response) VisitPushChannelContentResponse ¶
func (response PushChannelContent200Response) VisitPushChannelContentResponse(w http.ResponseWriter) error
type PushChannelContent400JSONResponse ¶
type PushChannelContent400JSONResponse Error
func (PushChannelContent400JSONResponse) VisitPushChannelContentResponse ¶
func (response PushChannelContent400JSONResponse) VisitPushChannelContentResponse(w http.ResponseWriter) error
type PushChannelContent404JSONResponse ¶
type PushChannelContent404JSONResponse Error
func (PushChannelContent404JSONResponse) VisitPushChannelContentResponse ¶
func (response PushChannelContent404JSONResponse) VisitPushChannelContentResponse(w http.ResponseWriter) error
type PushChannelContentJSONRequestBody ¶
type PushChannelContentJSONRequestBody = PushAppletRequest
PushChannelContentJSONRequestBody defines body for PushChannelContent for application/json ContentType.
type PushChannelContentMultipartBody ¶
type PushChannelContentMultipartBody struct {
// Duration Display duration in seconds (default 15, 0 for indefinite)
Duration *int `json:"duration,omitempty"`
// Image WebP image (max 128KB, must be 64x32)
Image openapi_types.File `json:"image"`
}
PushChannelContentMultipartBody defines parameters for PushChannelContent.
type PushChannelContentMultipartRequestBody ¶
type PushChannelContentMultipartRequestBody PushChannelContentMultipartBody
PushChannelContentMultipartRequestBody defines body for PushChannelContent for multipart/form-data ContentType.
type PushChannelContentRequestObject ¶
type PushChannelContentRequestObject struct {
UUID openapi_types.UUID `json:"uuid"`
JSONBody *PushChannelContentJSONRequestBody
MultipartBody *multipart.Reader
}
type PushChannelContentResponseObject ¶
type PushChannelContentResponseObject interface {
VisitPushChannelContentResponse(w http.ResponseWriter) error
}
type PushChannelContentdefaultJSONResponse ¶
func (PushChannelContentdefaultJSONResponse) VisitPushChannelContentResponse ¶
func (response PushChannelContentdefaultJSONResponse) VisitPushChannelContentResponse(w http.ResponseWriter) error
type PushDeviceContent200Response ¶
type PushDeviceContent200Response struct {
}
func (PushDeviceContent200Response) VisitPushDeviceContentResponse ¶
func (response PushDeviceContent200Response) VisitPushDeviceContentResponse(w http.ResponseWriter) error
type PushDeviceContent400JSONResponse ¶
type PushDeviceContent400JSONResponse Error
func (PushDeviceContent400JSONResponse) VisitPushDeviceContentResponse ¶
func (response PushDeviceContent400JSONResponse) VisitPushDeviceContentResponse(w http.ResponseWriter) error
type PushDeviceContent404JSONResponse ¶
type PushDeviceContent404JSONResponse Error
func (PushDeviceContent404JSONResponse) VisitPushDeviceContentResponse ¶
func (response PushDeviceContent404JSONResponse) VisitPushDeviceContentResponse(w http.ResponseWriter) error
type PushDeviceContent409JSONResponse ¶
type PushDeviceContent409JSONResponse Error
func (PushDeviceContent409JSONResponse) VisitPushDeviceContentResponse ¶
func (response PushDeviceContent409JSONResponse) VisitPushDeviceContentResponse(w http.ResponseWriter) error
type PushDeviceContentJSONRequestBody ¶
type PushDeviceContentJSONRequestBody = PushAppletRequest
PushDeviceContentJSONRequestBody defines body for PushDeviceContent for application/json ContentType.
type PushDeviceContentMultipartBody ¶
type PushDeviceContentMultipartBody struct {
// Duration Display duration in seconds (default 15, 0 for indefinite)
Duration *int `json:"duration,omitempty"`
// Image WebP image (max 128KB, must be 64x32)
Image openapi_types.File `json:"image"`
}
PushDeviceContentMultipartBody defines parameters for PushDeviceContent.
type PushDeviceContentMultipartRequestBody ¶
type PushDeviceContentMultipartRequestBody PushDeviceContentMultipartBody
PushDeviceContentMultipartRequestBody defines body for PushDeviceContent for multipart/form-data ContentType.
type PushDeviceContentRequestObject ¶
type PushDeviceContentRequestObject struct {
UUID openapi_types.UUID `json:"uuid"`
JSONBody *PushDeviceContentJSONRequestBody
MultipartBody *multipart.Reader
}
type PushDeviceContentResponseObject ¶
type PushDeviceContentResponseObject interface {
VisitPushDeviceContentResponse(w http.ResponseWriter) error
}
type PushDeviceContentdefaultJSONResponse ¶
func (PushDeviceContentdefaultJSONResponse) VisitPushDeviceContentResponse ¶
func (response PushDeviceContentdefaultJSONResponse) VisitPushDeviceContentResponse(w http.ResponseWriter) error
type RenderApplet200ImagewebpResponse ¶
func (RenderApplet200ImagewebpResponse) VisitRenderAppletResponse ¶
func (response RenderApplet200ImagewebpResponse) VisitRenderAppletResponse(w http.ResponseWriter) error
type RenderApplet404JSONResponse ¶
type RenderApplet404JSONResponse Error
func (RenderApplet404JSONResponse) VisitRenderAppletResponse ¶
func (response RenderApplet404JSONResponse) VisitRenderAppletResponse(w http.ResponseWriter) error
type RenderAppletParams ¶
type RenderAppletParams struct {
// Config JSON configuration for the applet
Config *string `form:"config,omitempty" json:"config,omitempty"`
}
RenderAppletParams defines parameters for RenderApplet.
type RenderAppletRequestObject ¶
type RenderAppletRequestObject struct {
Id string `json:"id"`
Params RenderAppletParams
}
type RenderAppletResponseObject ¶
type RenderAppletResponseObject interface {
VisitRenderAppletResponse(w http.ResponseWriter) error
}
type RenderAppletdefaultJSONResponse ¶
func (RenderAppletdefaultJSONResponse) VisitRenderAppletResponse ¶
func (response RenderAppletdefaultJSONResponse) VisitRenderAppletResponse(w http.ResponseWriter) error
type RequiredHeaderError ¶
func (*RequiredHeaderError) Error ¶
func (e *RequiredHeaderError) Error() string
func (*RequiredHeaderError) Unwrap ¶
func (e *RequiredHeaderError) Unwrap() error
type RequiredParamError ¶
type RequiredParamError struct {
ParamName string
}
func (*RequiredParamError) Error ¶
func (e *RequiredParamError) Error() string
type SchemaOption ¶
type SchemaOption = schema.SchemaOption
SchemaOption defines model for SchemaOption.
type SchemaVisibility ¶
type SchemaVisibility = schema.SchemaVisibility
SchemaVisibility defines model for SchemaVisibility.
type SearchLocations200JSONResponse ¶
type SearchLocations200JSONResponse []Location
func (SearchLocations200JSONResponse) VisitSearchLocationsResponse ¶
func (response SearchLocations200JSONResponse) VisitSearchLocationsResponse(w http.ResponseWriter) error
type SearchLocationsParams ¶
type SearchLocationsParams struct {
// Q Search query
Q string `form:"q" json:"q"`
// Limit Maximum number of results
Limit *int `form:"limit,omitempty" json:"limit,omitempty"`
}
SearchLocationsParams defines parameters for SearchLocations.
type SearchLocationsRequestObject ¶
type SearchLocationsRequestObject struct {
Params SearchLocationsParams
}
type SearchLocationsResponseObject ¶
type SearchLocationsResponseObject interface {
VisitSearchLocationsResponse(w http.ResponseWriter) error
}
type SearchLocationsdefaultJSONResponse ¶
func (SearchLocationsdefaultJSONResponse) VisitSearchLocationsResponse ¶
func (response SearchLocationsdefaultJSONResponse) VisitSearchLocationsResponse(w http.ResponseWriter) error
type Server ¶
type Server struct {
// contains filtered or unexported fields
}
func (*Server) ClearChannelPush ¶
func (s *Server) ClearChannelPush(ctx context.Context, request ClearChannelPushRequestObject) (ClearChannelPushResponseObject, error)
ClearChannelPush handles DELETE /channels/{uuid}/push
func (*Server) ClearDevicePush ¶
func (s *Server) ClearDevicePush(ctx context.Context, request ClearDevicePushRequestObject) (ClearDevicePushResponseObject, error)
ClearDevicePush handles DELETE /devices/{uuid}/push
func (*Server) CreateChannel ¶
func (s *Server) CreateChannel(ctx context.Context, request CreateChannelRequestObject) (CreateChannelResponseObject, error)
func (*Server) CreateChannelApplet ¶
func (s *Server) CreateChannelApplet(ctx context.Context, request CreateChannelAppletRequestObject) (CreateChannelAppletResponseObject, error)
func (*Server) DeleteChannel ¶
func (s *Server) DeleteChannel(ctx context.Context, request DeleteChannelRequestObject) (DeleteChannelResponseObject, error)
func (*Server) DeleteChannelApplet ¶
func (s *Server) DeleteChannelApplet(ctx context.Context, request DeleteChannelAppletRequestObject) (DeleteChannelAppletResponseObject, error)
func (*Server) DeleteDevice ¶
func (s *Server) DeleteDevice(ctx context.Context, request DeleteDeviceRequestObject) (DeleteDeviceResponseObject, error)
func (*Server) FindChannelByUUID ¶
func (s *Server) FindChannelByUUID(ctx context.Context, request FindChannelByUUIDRequestObject) (FindChannelByUUIDResponseObject, error)
func (*Server) GetAppletByID ¶
func (s *Server) GetAppletByID(ctx context.Context, request GetAppletByIDRequestObject) (GetAppletByIDResponseObject, error)
func (*Server) GetApplets ¶
func (s *Server) GetApplets(ctx context.Context, request GetAppletsRequestObject) (GetAppletsResponseObject, error)
func (*Server) GetChannels ¶
func (s *Server) GetChannels(ctx context.Context, request GetChannelsRequestObject) (GetChannelsResponseObject, error)
func (*Server) GetDeviceByUUID ¶
func (s *Server) GetDeviceByUUID(ctx context.Context, request GetDeviceByUUIDRequestObject) (GetDeviceByUUIDResponseObject, error)
func (*Server) GetDevices ¶
func (s *Server) GetDevices(ctx context.Context, request GetDevicesRequestObject) (GetDevicesResponseObject, error)
func (*Server) GetLocationByPlaceID ¶
func (s *Server) GetLocationByPlaceID(ctx context.Context, request GetLocationByPlaceIDRequestObject) (GetLocationByPlaceIDResponseObject, error)
func (*Server) GetSessions ¶
func (s *Server) GetSessions(ctx context.Context, request GetSessionsRequestObject) (GetSessionsResponseObject, error)
func (*Server) PatchChannel ¶
func (s *Server) PatchChannel(ctx context.Context, request PatchChannelRequestObject) (PatchChannelResponseObject, error)
func (*Server) PatchChannelApplet ¶
func (s *Server) PatchChannelApplet(ctx context.Context, request PatchChannelAppletRequestObject) (PatchChannelAppletResponseObject, error)
func (*Server) PatchDevice ¶
func (s *Server) PatchDevice(ctx context.Context, request PatchDeviceRequestObject) (PatchDeviceResponseObject, error)
func (*Server) PushChannelContent ¶
func (s *Server) PushChannelContent(ctx context.Context, request PushChannelContentRequestObject) (PushChannelContentResponseObject, error)
PushChannelContent handles POST /channels/{uuid}/push
func (*Server) PushDeviceContent ¶
func (s *Server) PushDeviceContent(ctx context.Context, request PushDeviceContentRequestObject) (PushDeviceContentResponseObject, error)
PushDeviceContent handles POST /devices/{uuid}/push
func (*Server) RenderApplet ¶
func (s *Server) RenderApplet(ctx context.Context, request RenderAppletRequestObject) (RenderAppletResponseObject, error)
func (*Server) SearchLocations ¶
func (s *Server) SearchLocations(ctx context.Context, request SearchLocationsRequestObject) (SearchLocationsResponseObject, error)
type ServerInterface ¶
type ServerInterface interface {
// List available apps
// (GET /applets)
GetApplets(w http.ResponseWriter, r *http.Request, params GetAppletsParams)
// Get the details of an app
// (GET /applets/{id})
GetAppletByID(w http.ResponseWriter, r *http.Request, id string)
// Render an applet with config
// (GET /applets/{id}/render)
RenderApplet(w http.ResponseWriter, r *http.Request, id string, params RenderAppletParams)
// (GET /channels)
GetChannels(w http.ResponseWriter, r *http.Request)
// (POST /channels)
CreateChannel(w http.ResponseWriter, r *http.Request)
// (POST /channels/{channelUUID}/applets)
CreateChannelApplet(w http.ResponseWriter, r *http.Request, channelUUID openapi_types.UUID)
// (DELETE /channels/{channelUUID}/applets/{appletUUID})
DeleteChannelApplet(w http.ResponseWriter, r *http.Request, channelUUID openapi_types.UUID, appletUUID openapi_types.UUID)
// (PATCH /channels/{channelUUID}/applets/{appletUUID})
PatchChannelApplet(w http.ResponseWriter, r *http.Request, channelUUID openapi_types.UUID, appletUUID openapi_types.UUID)
// (DELETE /channels/{uuid})
DeleteChannel(w http.ResponseWriter, r *http.Request, uuid openapi_types.UUID)
// (GET /channels/{uuid})
FindChannelByUUID(w http.ResponseWriter, r *http.Request, uuid openapi_types.UUID)
// (PATCH /channels/{uuid})
PatchChannel(w http.ResponseWriter, r *http.Request, uuid openapi_types.UUID)
// Clear channel push override
// (DELETE /channels/{uuid}/push)
ClearChannelPush(w http.ResponseWriter, r *http.Request, uuid openapi_types.UUID)
// Push temporary content to channel
// (POST /channels/{uuid}/push)
PushChannelContent(w http.ResponseWriter, r *http.Request, uuid openapi_types.UUID)
// Get configured devices
// (GET /devices)
GetDevices(w http.ResponseWriter, r *http.Request)
// (DELETE /devices/{uuid})
DeleteDevice(w http.ResponseWriter, r *http.Request, uuid openapi_types.UUID)
// (GET /devices/{uuid})
GetDeviceByUUID(w http.ResponseWriter, r *http.Request, uuid openapi_types.UUID)
// (PATCH /devices/{uuid})
PatchDevice(w http.ResponseWriter, r *http.Request, uuid openapi_types.UUID)
// Clear device push override
// (DELETE /devices/{uuid}/push)
ClearDevicePush(w http.ResponseWriter, r *http.Request, uuid openapi_types.UUID)
// Push temporary content to device
// (POST /devices/{uuid}/push)
PushDeviceContent(w http.ResponseWriter, r *http.Request, uuid openapi_types.UUID)
// Search locations
// (GET /locations)
SearchLocations(w http.ResponseWriter, r *http.Request, params SearchLocationsParams)
// Get location by place ID
// (GET /locations/{placeId})
GetLocationByPlaceID(w http.ResponseWriter, r *http.Request, placeId string)
// Get connected sessions
// (GET /sessions)
GetSessions(w http.ResponseWriter, r *http.Request)
}
ServerInterface represents all server handlers.
func NewStrictHandler ¶
func NewStrictHandler(ssi StrictServerInterface, middlewares []StrictMiddlewareFunc) ServerInterface
func NewStrictHandlerWithOptions ¶
func NewStrictHandlerWithOptions(ssi StrictServerInterface, middlewares []StrictMiddlewareFunc, options StrictHTTPServerOptions) ServerInterface
type ServerInterfaceWrapper ¶
type ServerInterfaceWrapper struct {
Handler ServerInterface
HandlerMiddlewares []MiddlewareFunc
ErrorHandlerFunc func(w http.ResponseWriter, r *http.Request, err error)
}
ServerInterfaceWrapper converts contexts to parameters.
func (*ServerInterfaceWrapper) ClearChannelPush ¶
func (siw *ServerInterfaceWrapper) ClearChannelPush(w http.ResponseWriter, r *http.Request)
ClearChannelPush operation middleware
func (*ServerInterfaceWrapper) ClearDevicePush ¶
func (siw *ServerInterfaceWrapper) ClearDevicePush(w http.ResponseWriter, r *http.Request)
ClearDevicePush operation middleware
func (*ServerInterfaceWrapper) CreateChannel ¶
func (siw *ServerInterfaceWrapper) CreateChannel(w http.ResponseWriter, r *http.Request)
CreateChannel operation middleware
func (*ServerInterfaceWrapper) CreateChannelApplet ¶
func (siw *ServerInterfaceWrapper) CreateChannelApplet(w http.ResponseWriter, r *http.Request)
CreateChannelApplet operation middleware
func (*ServerInterfaceWrapper) DeleteChannel ¶
func (siw *ServerInterfaceWrapper) DeleteChannel(w http.ResponseWriter, r *http.Request)
DeleteChannel operation middleware
func (*ServerInterfaceWrapper) DeleteChannelApplet ¶
func (siw *ServerInterfaceWrapper) DeleteChannelApplet(w http.ResponseWriter, r *http.Request)
DeleteChannelApplet operation middleware
func (*ServerInterfaceWrapper) DeleteDevice ¶
func (siw *ServerInterfaceWrapper) DeleteDevice(w http.ResponseWriter, r *http.Request)
DeleteDevice operation middleware
func (*ServerInterfaceWrapper) FindChannelByUUID ¶
func (siw *ServerInterfaceWrapper) FindChannelByUUID(w http.ResponseWriter, r *http.Request)
FindChannelByUUID operation middleware
func (*ServerInterfaceWrapper) GetAppletByID ¶
func (siw *ServerInterfaceWrapper) GetAppletByID(w http.ResponseWriter, r *http.Request)
GetAppletByID operation middleware
func (*ServerInterfaceWrapper) GetApplets ¶
func (siw *ServerInterfaceWrapper) GetApplets(w http.ResponseWriter, r *http.Request)
GetApplets operation middleware
func (*ServerInterfaceWrapper) GetChannels ¶
func (siw *ServerInterfaceWrapper) GetChannels(w http.ResponseWriter, r *http.Request)
GetChannels operation middleware
func (*ServerInterfaceWrapper) GetDeviceByUUID ¶
func (siw *ServerInterfaceWrapper) GetDeviceByUUID(w http.ResponseWriter, r *http.Request)
GetDeviceByUUID operation middleware
func (*ServerInterfaceWrapper) GetDevices ¶
func (siw *ServerInterfaceWrapper) GetDevices(w http.ResponseWriter, r *http.Request)
GetDevices operation middleware
func (*ServerInterfaceWrapper) GetLocationByPlaceID ¶
func (siw *ServerInterfaceWrapper) GetLocationByPlaceID(w http.ResponseWriter, r *http.Request)
GetLocationByPlaceID operation middleware
func (*ServerInterfaceWrapper) GetSessions ¶
func (siw *ServerInterfaceWrapper) GetSessions(w http.ResponseWriter, r *http.Request)
GetSessions operation middleware
func (*ServerInterfaceWrapper) PatchChannel ¶
func (siw *ServerInterfaceWrapper) PatchChannel(w http.ResponseWriter, r *http.Request)
PatchChannel operation middleware
func (*ServerInterfaceWrapper) PatchChannelApplet ¶
func (siw *ServerInterfaceWrapper) PatchChannelApplet(w http.ResponseWriter, r *http.Request)
PatchChannelApplet operation middleware
func (*ServerInterfaceWrapper) PatchDevice ¶
func (siw *ServerInterfaceWrapper) PatchDevice(w http.ResponseWriter, r *http.Request)
PatchDevice operation middleware
func (*ServerInterfaceWrapper) PushChannelContent ¶
func (siw *ServerInterfaceWrapper) PushChannelContent(w http.ResponseWriter, r *http.Request)
PushChannelContent operation middleware
func (*ServerInterfaceWrapper) PushDeviceContent ¶
func (siw *ServerInterfaceWrapper) PushDeviceContent(w http.ResponseWriter, r *http.Request)
PushDeviceContent operation middleware
func (*ServerInterfaceWrapper) RenderApplet ¶
func (siw *ServerInterfaceWrapper) RenderApplet(w http.ResponseWriter, r *http.Request)
RenderApplet operation middleware
func (*ServerInterfaceWrapper) SearchLocations ¶
func (siw *ServerInterfaceWrapper) SearchLocations(w http.ResponseWriter, r *http.Request)
SearchLocations operation middleware
type SessionSummary ¶
type SessionSummary struct {
Channel *ChannelRef `json:"channel,omitempty"`
Device *DeviceRef `json:"device,omitempty"`
// ID Session ID
ID *uint32 `json:"id,omitempty"`
// RemoteAddr Remote IP address
RemoteAddr *string `json:"remote-addr,omitempty"`
}
SessionSummary defines model for SessionSummary.
type StdHTTPServerOptions ¶
type StdHTTPServerOptions struct {
BaseURL string
BaseRouter *http.ServeMux
Middlewares []MiddlewareFunc
ErrorHandlerFunc func(w http.ResponseWriter, r *http.Request, err error)
}
type StrictHTTPServerOptions ¶
type StrictHTTPServerOptions struct {
RequestErrorHandlerFunc func(w http.ResponseWriter, r *http.Request, err error)
ResponseErrorHandlerFunc func(w http.ResponseWriter, r *http.Request, err error)
}
func ServerOptions ¶
func ServerOptions() StrictHTTPServerOptions
type StrictHandlerFunc ¶
type StrictHandlerFunc = strictnethttp.StrictHTTPHandlerFunc
type StrictMiddlewareFunc ¶
type StrictMiddlewareFunc = strictnethttp.StrictHTTPMiddlewareFunc
type StrictServerInterface ¶
type StrictServerInterface interface {
// List available apps
// (GET /applets)
GetApplets(ctx context.Context, request GetAppletsRequestObject) (GetAppletsResponseObject, error)
// Get the details of an app
// (GET /applets/{id})
GetAppletByID(ctx context.Context, request GetAppletByIDRequestObject) (GetAppletByIDResponseObject, error)
// Render an applet with config
// (GET /applets/{id}/render)
RenderApplet(ctx context.Context, request RenderAppletRequestObject) (RenderAppletResponseObject, error)
// (GET /channels)
GetChannels(ctx context.Context, request GetChannelsRequestObject) (GetChannelsResponseObject, error)
// (POST /channels)
CreateChannel(ctx context.Context, request CreateChannelRequestObject) (CreateChannelResponseObject, error)
// (POST /channels/{channelUUID}/applets)
CreateChannelApplet(ctx context.Context, request CreateChannelAppletRequestObject) (CreateChannelAppletResponseObject, error)
// (DELETE /channels/{channelUUID}/applets/{appletUUID})
DeleteChannelApplet(ctx context.Context, request DeleteChannelAppletRequestObject) (DeleteChannelAppletResponseObject, error)
// (PATCH /channels/{channelUUID}/applets/{appletUUID})
PatchChannelApplet(ctx context.Context, request PatchChannelAppletRequestObject) (PatchChannelAppletResponseObject, error)
// (DELETE /channels/{uuid})
DeleteChannel(ctx context.Context, request DeleteChannelRequestObject) (DeleteChannelResponseObject, error)
// (GET /channels/{uuid})
FindChannelByUUID(ctx context.Context, request FindChannelByUUIDRequestObject) (FindChannelByUUIDResponseObject, error)
// (PATCH /channels/{uuid})
PatchChannel(ctx context.Context, request PatchChannelRequestObject) (PatchChannelResponseObject, error)
// Clear channel push override
// (DELETE /channels/{uuid}/push)
ClearChannelPush(ctx context.Context, request ClearChannelPushRequestObject) (ClearChannelPushResponseObject, error)
// Push temporary content to channel
// (POST /channels/{uuid}/push)
PushChannelContent(ctx context.Context, request PushChannelContentRequestObject) (PushChannelContentResponseObject, error)
// Get configured devices
// (GET /devices)
GetDevices(ctx context.Context, request GetDevicesRequestObject) (GetDevicesResponseObject, error)
// (DELETE /devices/{uuid})
DeleteDevice(ctx context.Context, request DeleteDeviceRequestObject) (DeleteDeviceResponseObject, error)
// (GET /devices/{uuid})
GetDeviceByUUID(ctx context.Context, request GetDeviceByUUIDRequestObject) (GetDeviceByUUIDResponseObject, error)
// (PATCH /devices/{uuid})
PatchDevice(ctx context.Context, request PatchDeviceRequestObject) (PatchDeviceResponseObject, error)
// Clear device push override
// (DELETE /devices/{uuid}/push)
ClearDevicePush(ctx context.Context, request ClearDevicePushRequestObject) (ClearDevicePushResponseObject, error)
// Push temporary content to device
// (POST /devices/{uuid}/push)
PushDeviceContent(ctx context.Context, request PushDeviceContentRequestObject) (PushDeviceContentResponseObject, error)
// Search locations
// (GET /locations)
SearchLocations(ctx context.Context, request SearchLocationsRequestObject) (SearchLocationsResponseObject, error)
// Get location by place ID
// (GET /locations/{placeId})
GetLocationByPlaceID(ctx context.Context, request GetLocationByPlaceIDRequestObject) (GetLocationByPlaceIDResponseObject, error)
// Get connected sessions
// (GET /sessions)
GetSessions(ctx context.Context, request GetSessionsRequestObject) (GetSessionsResponseObject, error)
}
StrictServerInterface represents all server handlers.
type TooManyValuesForParamError ¶
func (*TooManyValuesForParamError) Error ¶
func (e *TooManyValuesForParamError) Error() string
type UnescapedCookieParamError ¶
func (*UnescapedCookieParamError) Error ¶
func (e *UnescapedCookieParamError) Error() string
func (*UnescapedCookieParamError) Unwrap ¶
func (e *UnescapedCookieParamError) Unwrap() error
type UnmarshalingParamError ¶
func (*UnmarshalingParamError) Error ¶
func (e *UnmarshalingParamError) Error() string
func (*UnmarshalingParamError) Unwrap ¶
func (e *UnmarshalingParamError) Unwrap() error